@@ -32,6 +32,7 @@ public:
         NameRole = Qt::DisplayRole,
         IconNameRole = Qt::DecorationRole,
         DescriptionRole = Qt::UserRole + 1,
+        IdRole = Qt::UserRole + 2,
         KcmRole,
     };
 
@@ -44,7 +45,5 @@ public:
     QHash<int, QByteArray> roleNames() const override;
 
 private:
-    KQuickAddons::ConfigModule *instantiateKcm(const QString &name) const;
-
     QVector<Data> m_plugins;
 };
